@@ -4,7 +4,8 @@
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
-  License version 2.1 as published by the Free Software Foundation.
+  License as published by the Free Software Foundation; either
+  version 2.1 of the License, or (at your option) any later version.
 
   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -40,23 +41,23 @@ typedef struct {
   bool unify_kana_case;
   bool unify_kana_voiced_sound_mark;
   bool unify_hyphen;
-  grn_bool unify_prolonged_sound_mark;
+  bool unify_prolonged_sound_mark;
   bool unify_hyphen_and_prolonged_sound_mark;
-  grn_bool unify_middle_dot;
-  grn_bool unify_katakana_v_sounds;
-  grn_bool unify_katakana_bu_sound;
-  grn_bool unify_katakana_du_small_sounds;
-  grn_bool unify_katakana_du_sound;
-  grn_bool unify_katakana_zu_small_sounds;
-  grn_bool unify_katakana_wo_sound;
-  grn_bool unify_katakana_di_sound;
-  grn_bool unify_katakana_gu_small_sounds;
+  bool unify_middle_dot;
+  bool unify_katakana_v_sounds;
+  bool unify_katakana_bu_sound;
+  bool unify_katakana_du_small_sounds;
+  bool unify_katakana_du_sound;
+  bool unify_katakana_zu_small_sounds;
+  bool unify_katakana_wo_sound;
+  bool unify_katakana_di_sound;
+  bool unify_katakana_gu_small_sounds;
   bool unify_kana_hyphen;
   bool unify_kana_prolonged_sound_mark;
   bool unify_katakana_trailing_o;
   bool unify_to_romaji;
   bool unify_to_katakana;
-  grn_bool remove_blank;
+  bool remove_blank;
   bool remove_blank_force;
   bool remove_blank_force_is_set;
   bool remove_new_line;
